@@ -71,7 +71,7 @@ def model_dict_to_str(
         # if enum, turn to str cast instead
         type_cast_str = re.sub(r"default::\w+", "std::str", type_cast_str)
         field_str = f"{field_name} := <{type_cast_str}>${variable_name}"
-        if type_cast_str.endswith("::str") and (
+        if (type_cast_str.endswith("::str") or type_cast_str.endswith("::json")) and (
             isinstance(val, dict) or isinstance(val, list)
         ):
             # for basemodel subfields that should go from dict to str
@@ -427,7 +427,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
             for field_name, value in d.items():
                 if cast := cls._edgedb_conversion_map.get(field_name, {}).get("cast"):
                     if (
-                        cast.endswith("::str")
+                        (cast.endswith("::str") or cast.endswith("::json"))
                         and not isinstance(value, str)
                         and not type(value) in [set]
                     ):
